rainiee_data
===============
* easy to use as most of the data returned are json 

Installation
--------------

    pip install rainiee_data_test==2.2.0
    from rainiee_data_test.data_client import DataClient
    client = DataClient(username,password)

Upgrade
---------------

    pip install rainiee_data_test --upgrade

Quick Start
--------------
cn_index

        1: cn_index_basic
            rainiee_client.cn_index_basic('SSE')  #//SSE = 上交所指数 SZSE = 深交所指数
        2: cn_index_composition
            rainiee_client.cn_index_composition('000001.SH')
        3: cn_index_composition_weight
            rainiee_client.cn_index_composition_weight('000001.SH')
        4: cn_index_eod
            rainiee_client.cn_index_eod('399654.SZ',564,600)    


cn_stock

        1: cn_stock_eod
            -- 获取未复权数据，日k线
            rainiee_client.cn_stock_eod('300647.sz',2581,2581)
            -- 获取前复权数据，日k线
            rainiee_client.cn_stock_eod('300647.sz',2581,2681,'qfq')
            -- 获取未复权数据，5分钟行情
            rainiee_client.cn_stock_eod('300647.sz',2581,2681,None,5)
            
        2: cn_stock_realtime
            rainiee_client.cn_stock_realtime('300647.sz')
        3: cn_symbol_list
            rainiee_client.cn_symbol_list('chuangyeban')

cn_stockstats

        1: cn_stockstats_list
              rainiee_client.cn_stockstats_list('300647.sz',2581,2581)
        2: cn_stockstats_sort
              rainiee_client.cn_stockstats_sort('daily_return_ma5',2581,2581)
        3: cn_stockstats_top_turnover_rate
              rainiee_client.cn_stockstats_top_turnover_rate(20,2581)
        4: cn_stockstats_is_enter_market
              rainiee_client.cn_stockstats_is_enter_market(2581,1.03,13)
        5: cn_stockstats_latest_returns
              rainiee_client.cn_stockstats_latest_returns('300647.sz',20)
        6: cn_stockstats_eod_portf_return   
              portf = [{'percentage':1.0,'symbol':'300547.sz'},{'percentage':0.5,'symbol':'300647.sz'}]
              rainiee_client.cn_stockstats_eod_portf_return(portf,2581))
index

       1：get_trade_index
               start_index = client.get_trade_index('20200731')
       2：get_trade_date
               start_index = client.get_trade_date(2571)
        
        